@@ -5,7 +5,7 @@ use Carp;
 use FindBin;
 # sigh. Test::Deep exports reftype, blessed (and much more) so don't import from Scalar::Util
 # use Scalar::Util qw(looks_like_number reftype blessed);
-use Scalar::Util qw(looks_like_number refaddr);
+use Scalar::Util qw(looks_like_number);
 use List::Util qw(min max);
 use List::MoreUtils qw(uniq);
 use Data::Rmap ();
@@ -29,22 +29,21 @@ use Hash::AutoHash::Args;
 use Exporter();
 
 our @ISA=qw(Exporter);
-our @EXPORT=qw(group groupmap gentle_uniq
-	       create_autodb_table autodb dbh oid2obj obj2oid all_objects
+our @EXPORT=qw(group groupmap 
+	       create_autodb_table autodb dbh
 	       tie_oid %oid %oid2id %id2oid %obj2oid %oid2obj
 	       id id_restore id_next next_id
 	       reach reach_fetch reach_mark
 	       ok_dbtables _ok_dbtables ok_dbcolumns _ok_dbcolumns
 	       ok_basetable ok_listtable ok_collection ok_collections
 	       _ok_basetable _ok_listtable _ok_collection _ok_collections
-	       ok_oldoid ok_oldoids ok_newoid ok_newoids ok_deloid ok_deloids
-	       _ok_oldoid _ok_newoid _ok_deloid
-	       ok_objcache conjure_oid
-	       cmp_thawed _cmp_thawed cmp_details
+	       ok_oldoid ok_oldoids ok_newoid ok_newoids
+	       _ok_oldoid _ok_oldoids _ok_newoid _ok_newoids
+	       cmp_thawed _cmp_thawed
 	       remember_oids
 	       test_single 
 	       actual_tables actual_counts norm_counts actual_columns
-	       report report_pass report_fail called_from
+	       report report_pass report_fail
 	     );
 # TODO: database name should be configurable
 # CAUTION: $test_db and $SDBM_dir duplicated in Build.PL
@@ -77,16 +76,6 @@ sub groupmap (&@) {
   }
   wantarray? %groups: \%groups;
 }
-# uniq-ify a list gently, so Oids not fetched.
-sub gentle_uniq {
-  my(%seen,@uniq);
-  for (@_) {
-    my $key=ref($_)? refaddr($_): $_;
-    push(@uniq,$_) unless $seen{$key};
-    $seen{$key}++;
-  }
-  @uniq;
-}
 
 # used in serialize_ok tests. someday in Developer/Serialize tests
 sub create_autodb_table {
@@ -102,16 +91,11 @@ sub create_autodb_table {
   undef;
 }
 sub autodb {$Class::AutoDB::GLOBALS->autodb}
-sub oid2obj {Class::AutoDB::Serialize->oid2obj(@_)}
-sub obj2oid {Class::AutoDB::Serialize->obj2oid(@_)}
-sub all_objects {values %{Class::AutoDB::Globals->instance()->oid2obj}}
-
 sub dbh {my $autodb=autodb; $autodb? $autodb->dbh: _dbh()}
 our $MYSQL_dbh;
-# NG 13-10-23: changed connect to use $ENV{USER} instead of undef. should be equivalent, but...
 sub _dbh {
   $MYSQL_dbh or $MYSQL_dbh=DBI->connect
-    ("dbi:mysql:database=$test_db",$ENV{USER},undef,
+    ("dbi:mysql:database=$test_db",undef,undef,
      {AutoCommit=>1, ChopBlanks=>1, PrintError=>0, PrintWarn=>0, Warn=>0,});
 }
 # hashes below are exported.
@@ -303,55 +287,51 @@ sub _ok_collection {
 # check that object's oid looks okay and is old
 # @tables no longer used since loop that checks oids vs. tables commented out
 sub ok_oldoid {
-  my($object,$label)=@_;
+  my($object,$label,@tables)=@_;
   my($package,$file,$line)=caller; # for fails
-  my $ok=_ok_oldoid($object,$label,$file,$line);
+  my $ok=_ok_oldoid($object,$label,$file,$line,@tables);
   report_pass($ok,$label);
 }
 # check that objects' oids look okay and are old
 # @tables no longer used since loop that checks oids vs. tables commented out
 sub ok_oldoids {
-  my($objects,$label)=@_;
+  my($objects,$label,@tables)=@_;
   my($package,$file,$line)=caller; # for fails
   my $ok=1;
   for(my $i=0; $i<@$objects; $i++) {
-    $ok&&=_ok_oldoid($objects->[$i],"$label object $i",$file,$line);
+    $ok&&=_ok_oldoid($objects->[$i],"$label object $i",$file,$line,@tables);
   }
   report_pass($ok,$label);
 }
 # @tables no longer used since loop that checks oids vs. tables commented out
 sub _ok_oldoid {
-  my($obj,$label,$file,$line)=@_;
+  my($object,$label,$file,$line,@tables)=@_;
   tie_oid;
-  my $oid=autodb->oid($obj);
+  my $oid=autodb->oid($object);
   report_fail($oid>1,"$label: oid looks good",$file,$line) or return 0;
-  # first check in-memory state maintained by test
-  report_fail(exists $oid2obj{$oid}? $oid2obj{$oid}==$obj: 1,
+  # first check in-memory state
+  report_fail(exists $oid2obj{$oid}? $oid2obj{$oid}==$object: 1,
 	      "$label: oid-to-object unique",$file,$line) or return 0;
-  report_fail(exists $obj2oid{refaddr $obj}? $obj2oid{refaddr $obj}==$oid: 1,
+  report_fail(exists $obj2oid{$object}? $obj2oid{$object}==$oid: 1,
 	      "$label: object-to-oid unique",$file,$line) or return 0;
-  # update in-memory state maintained by test
-  $oid2obj{$oid}=$obj;
-  $obj2oid{refaddr $obj}=$oid;
-  # next check real object cache (similar to ok_objcache)
-  report_fail(oid2obj($oid)==$obj,"$label: cache entry for oid $oid",$file,$line) or return 0;
-  # NG 10-09-10: test below fails when putting deleted objects.  d'oh...
-  # NG 10-09-11: changed calling program so uncommented test below
-  report_fail
-    (ref $obj ne 'Class::AutoDB::OidDeleted',
-     "$label: ref for oid $oid looks extant (not OidDeleted)",$file,$line) or return 0;
-  # third check against database maintained by test
+  # update in-memory state
+  $oid2obj{$oid}=$object;
+  $obj2oid{$object}=$oid;
+  # then check against database
   report_fail($oid{$oid},"$label: in oid SDBM file",$file,$line) or return 0;
-  if (UNIVERSAL::can($obj,'id')) {
-    my $id=$obj->id;
+  if (UNIVERSAL::can($object,'id')) {
+    my $id=$object->id;
     report_fail($oid2id{$oid}==$id,"$label: in oid2id SDBM file",$file,$line) or return 0;
     report_fail($id2oid{$id}==$oid,"$label: in id2oid SDBM file",$file,$line) or return 0;
   }
-  # last but not least check against real database 
-  #   just _AutoDB here. collections tested in ok_collections
-  # NG 10-09-09: added NOT NULL to support deleted objects
-  my($count)=dbh->selectrow_array
-    (qq(SELECT COUNT(oid) FROM _AutoDB WHERE oid=$oid AND object IS NOT NULL));
+  # this loop fails when object has list keys, but some lists are empty
+  # redundant with ok_collection anyway. just keep check against _AutoDB
+  #   push(@tables,'_AutoDB') unless grep {$_ eq '_AutoDB'} @tables;
+  #   for my $table (@tables) {
+  #     my($count)=dbh->selectrow_array(qq(SELECT COUNT(oid) FROM $table WHERE oid=$oid));
+  #     report_fail($count>=1,"$label: in $table table",$file,$line) or return 0;
+  #   }
+  my($count)=dbh->selectrow_array(qq(SELECT COUNT(oid) FROM _AutoDB WHERE oid=$oid));
   report_fail($count==1,"$label: $oid has count $count in _AutoDB table",$file,$line) or return 0;
 }
 
@@ -373,32 +353,26 @@ sub ok_newoids {
   report_pass($ok,$label);
 }
 sub _ok_newoid {
-  my($obj,$label,$file,$line,@tables)=@_;
+  my($object,$label,$file,$line,@tables)=@_;
   tie_oid;
-  my $oid=autodb->oid($obj);
+  my $oid=autodb->oid($object);
   report_fail($oid>1,"$label: oid looks good",$file,$line) or return 0;
-  # first check in-memory state maintained by test
-  report_fail(exists $oid2obj{$oid}? $oid2obj{$oid}==$obj: 1,
+  # first check in-memory state
+  report_fail(exists $oid2obj{$oid}? $oid2obj{$oid}==$object: 1,
 	      "$label: oid-to-object unique",$file,$line) or return 0;
-  report_fail(exists $obj2oid{refaddr $obj}? $obj2oid{refaddr $obj}==$oid: 1,
+  report_fail(exists $obj2oid{$object}? $obj2oid{$object}==$oid: 1,
 	      "$label: object-to-oid unique",$file,$line) or return 0;
-  # update in-memory state maintained by test
-  $oid2obj{$oid}=$obj;
-  $obj2oid{refaddr $obj}=$oid;
-  # next check real object cache (similar to ok_objcache)
-  report_fail(oid2obj($oid)==$obj,"$label: cache entry for oid $oid",$file,$line) or return 0;
-  report_fail
-    (ref($obj) ne 'Class::AutoDB::OidDeleted',
-     "$label: ref for oid $oid looks extant (not OidDeleted)",$file,$line) or return 0;
-  # third check against database maintained by test
+  # update in-memory state
+  $oid2obj{$oid}=$object;
+  $obj2oid{$object}=$oid;
+  # then check against database
   report_fail(!$oid{$oid},"$label: not in SDBM file",$file,$line) or return 0;
-  if (UNIVERSAL::can($obj,'id')) {
-    my $id=$obj->id;
+  if (UNIVERSAL::can($object,'id')) {
+    my $id=$object->id;
     report_fail(!$oid2id{$oid},"$label: in oid2id SDBM file",$file,$line) or return 0;
     # line below generates spurious errors when tests rerun
     # report_fail(!$id2oid{$id},"$label: in id2oid SDBM file",$file,$line) or return 0;
   }
-  # last but not least check against real database 
   push(@tables,'_AutoDB') unless grep {$_ eq '_AutoDB'} @tables;
   for my $table (@tables) {
     my($count)=dbh->selectrow_array(qq(SELECT COUNT(oid) FROM $table WHERE oid=$oid));
@@ -406,148 +380,6 @@ sub _ok_newoid {
   }
   1;
 }
-
-# check that object's oid looks okay and is deleted
-sub ok_deloid {
-  my($object,$label,@tables)=@_;
-  my($package,$file,$line)=caller; # for fails
-  my $ok=_ok_deloid($object,$label,$file,$line,@tables);
-  report_pass($ok,$label);
-}
-# check that objects' oids look okay and are deleted
-sub ok_deloids {
-  my($objects,$label,@tables)=@_;
-  my($package,$file,$line)=caller; # for fails
-  my $ok=1;
-  for(my $i=0; $i<@$objects; $i++) {
-    $ok&&=_ok_deloid($objects->[$i],"$label object $i",$file,$line,@tables);
-  }
-  report_pass($ok,$label);
-}
-sub _ok_deloid {
-  my($obj,$label,$file,$line,@tables)=@_;
-  tie_oid;
-  my $oid=autodb->oid($obj);
-  report_fail($oid>1,"$label: oid looks good",$file,$line) or return 0;
-  # first check in-memory state maintained by test
-  report_fail(exists $oid2obj{$oid}? $oid2obj{$oid}==$obj: 1,
-	      "$label: oid-to-object unique",$file,$line) or return 0;
-  report_fail(exists $obj2oid{refaddr $obj}? $obj2oid{refaddr $obj}==$oid: 1,
-	      "$label: object-to-oid unique",$file,$line) or return 0;
-  # update in-memory state maintained by test
-  $oid2obj{$oid}=$obj;
-  $obj2oid{refaddr $obj}=$oid;
-  # next check real object cache (similar to ok_objcache)
-  report_fail(oid2obj($oid)==$obj,"$label: cache entry for oid $oid",$file,$line) or return 0;
-  report_fail
-    (ref($obj) eq 'Class::AutoDB::OidDeleted',
-     "$label: ref for oid $oid looks deleted (is OidDeleted)",$file,$line) or return 0;
-  # third check against database maintained by test
-  # NG 10-09-10: tests fail when deleting old objects. kinda silly anyway since
-  #              just testing the test...
-  # report_fail(!$oid{$oid},"$label: not in SDBM file",$file,$line) or return 0;
-    if (UNIVERSAL::can($obj,'id')) {
-      my $id=$obj->id;
-      report_fail(!$oid2id{$oid},"$label: in oid2id SDBM file",$file,$line) or return 0;
-      # line below generates spurious errors when tests rerun
-      # report_fail(!$id2oid{$id},"$label: in id2oid SDBM file",$file,$line) or return 0;
-    }
-  # last but not least check against real database
-  # _AutoDB is special because deleted objects exist but are NULL
-  my($count)=dbh->selectrow_array
-    (qq(SELECT COUNT(oid) FROM _AutoDB WHERE oid=$oid AND object IS NULL));
-  report_fail
-    ($count==1,
-     "$label: $oid deleted (exists but is NULL) in _AutoDB table",$file,$line) or return 0;
-  for my $table (@tables) {
-    next if $table eq '_AutoDB';
-    my($count)=dbh->selectrow_array(qq(SELECT COUNT(oid) FROM $table WHERE oid=$oid));
-    report_fail(!$count,"$label: not in $table table",$file,$line) or return 0;
-  }
-  1;
-}
-
-
-# check entries in object cache, esp for Oid and OidDeleted objects
-# do it carefully to avoid inadvertent fetches! 
-#   I messed this up first couple of times.
-#   NEVER test $obj. always test ref $obj !!!
-# cache entry cab be specified by reference (ie, obj), oid as number, or both in either order
-# $entry_type can be 
-#   undef           entry should not exist
-#   object          entry should hold real object
-#   Oid, OidDeleted obvious
-sub ok_objcache {
-  my($obj,$oid);
-  ref $_[0]? $obj=shift: ($oid=shift); # 1st arg can be $obj or $oid
-				       # 2nd arg can be the other one or neither
-  !ref $obj && ref $_[0]? $obj=shift: (!$oid && $_[0]=~/^\d+$/? $oid=shift: undef);
-  my($entry_type,$class,$label,$file,$line,$no_report_pass)=@_;
-  
-  # set whichever of obj and oid not already set. if both set, check consistency
-  if (ref $obj && $oid) {
-    report_fail(oid2obj($oid)==$obj && obj2oid($obj)==$oid,
-		'object and oid do not match in ok_objcache',$file,$line);
-  } elsif (ref $obj) {
-    $oid=obj2oid($obj);
-  } elsif ($oid) {
-    $obj=oid2obj($oid);
-  } else {
-    confess "Invalid arguments: at least one of \$obj or \$oid must be specified";
-  }
-
-  my $ok=1;
-  if (!defined $entry_type) {	# expect obj to be undef
-    $ok&&=report_fail
-      (!defined $obj,"$label. cache entry should not exist",$file,$line);
-  } else {
-    my $ref=ref $obj;
-    if ($entry_type=~/^obj/i) {
-      $ok&&=report_fail
-	($ref eq $class,"$label: cache entry has wrong class: got $ref, expected $class",
-	 $file,$line);
-    } else {			# Oid or OidDeleted
-      confess "Ilegal entry_type $entry_type" unless $entry_type=~/oid$|deleted$/i;
-      my $correct_ref=$entry_type=~/oid$/i? 'Class::AutoDB::Oid': 'Class::AutoDB::OidDeleted';
-      $ok&&=report_fail
-	($ref eq $correct_ref,
-	 "$label. cache entry has wrong class: got $ref, expected $correct_ref",$file,$line);
-      my $oid_class=$obj->{_CLASS};
-      my $oid_oid=$obj->{_OID};
-      $ok&&=report_fail
-	($oid_oid==$oid,
-	 "$label. $entry_type contains wrong oid: got $oid_oid, expected $oid",$file,$line);
-      # Oid must have class. optional for OidDeleted
-      if ($entry_type=~/oid$/i || (defined $class && exists $obj->{_CLASS})) { 
-	$ok&&=report_fail
-	  ($oid_class eq $class,
-	   "$label. $entry_type contains wrong class: got $oid_class, expected $class",
-	   $file,$line);
-      }
-      # check for extraneous keys.
-      my @oid_keys=keys %$obj;
-      my $bad_keys=join(',',grep !/_CLASS|_OID/,@oid_keys);
-      $ok&&=report_fail(!$bad_keys,
-			"$label. $entry_type contains extraneous keys: $bad_keys",$file,$line);
-    }
-  }
-  !$no_report_pass? report_pass($ok,$label): $ok;
-}
-# conjure up Oid entries in object cache. returns entry in case anyone wants it (which they do :)
-use Class::AutoDB::Oid;
-use Class::AutoDB::OidDeleted;
-sub conjure_oid {
-  my($oid,$entry_type,$class)=@_;
-  confess "Ilegal entry_type $entry_type" unless $entry_type=~/oid$|deleted$/i;
-  my $obj={_OID=>$oid};
-  $obj->{_CLASS}=$class if defined $class;
-  bless $obj,$entry_type=~/oid$/i? 'Class::AutoDB::Oid': 'Class::AutoDB::OidDeleted';
-  oid2obj($oid,$obj);
-  obj2oid($obj,$oid);
-  $obj;
-}
-
-
 # TODO: use is all thawed tests!
 # $actual_objects. array of lots of object. 
 # $correct_thawed. subset of $actual_objects expected to be thawed
@@ -573,15 +405,14 @@ sub _cmp_thawed {
   my($ok,$details)=cmp_details(\@actual_refs,\@correct_refs);
   report_fail($ok,$label,$file,$line,$details);
 }
-# remember a list of oids or all oids for later tests
+# remember a list of oids for later tests
 sub remember_oids {
   tie_oid;
-  my @objs=@_? @_: all_objects;
-  my @oids=grep {$_>1} map {autodb->oid($_)} @objs;
+  my @oids=grep {$_>1} map {autodb->oid($_)} @_; # only remember good looking oids
   @oid{@oids}=@oids;
   # get id-able oids and corresponding ids
-  my @oids=grep {$_>1} map {autodb->oid($_)} grep {UNIVERSAL::can($_,'id')} @objs;
-  my @ids=map {autodb->oid($_)>1? $_->id: ()} grep {UNIVERSAL::can($_,'id')} @objs;
+  my @oids=grep {$_>1} map {autodb->oid($_)} grep {UNIVERSAL::can($_,'id')} @_;
+  my @ids=map {autodb->oid($_)>1? $_->id: ()} grep {UNIVERSAL::can($_,'id')} @_;
   @oid2id{@oids}=@ids;
   @id2oid{@ids}=@oids;
 }
@@ -600,11 +431,7 @@ sub actual_counts {
   my @tables=@_;
   my %counts;
   for my $table (@tables) {
-    # NG 10-09-09: added _AutoDB special case to handle deleted objects
-    my $sql=qq(SELECT COUNT(oid) FROM $table);
-    $sql.=' WHERE object IS NOT NULL' if $table eq '_AutoDB';
-    # my($count)=dbh->selectrow_array(qq(SELECT COUNT(oid) FROM $table));
-    my($count)=dbh->selectrow_array($sql);
+    my($count)=dbh->selectrow_array(qq(SELECT COUNT(oid) FROM $table));
     $counts{$table}=$count||0; # convert undef to 0 (usually nonexistent table)
   }
   wantarray? %counts: \%counts;
@@ -647,7 +474,6 @@ sub report {
   my($ok,$label,$file,$line,$details)=@_;
   pass($label), return if $ok;
   fail($label);
-  ($file,$line)=called_from($file,$line);
   diag("from $file line $line") if defined $file;
   if (defined $details) {
     diag(deep_diag($details)) if ref $details;
@@ -665,7 +491,6 @@ sub report_fail {
   my($ok,$label,$file,$line,$details)=@_;
   return 1 if $ok;
   fail($label);
-  ($file,$line)=called_from($file,$line);
   diag("from $file line $line") if defined $file;
   if (defined $details) {
     diag(deep_diag($details)) if ref $details;
@@ -673,14 +498,4 @@ sub report_fail {
   }
   return 0;
 }
-# set $file,$line if not already set
-sub called_from {
-  return @_ if $_[0];
-  my($package,$file,$line);
-  my $i=0;
-  while (($package,$file,$line)=caller($i++)) {
-    last if 'main' eq $package;
-  }
-  ($file,$line);
-}
 1;
